Prepares the data matrix X and the dependence structures U and Sigma for clustering and testing. If Sigma is not provided, it is estimated using an i.i.d. sample Y of the same variables,
with an associated dependence structure UY. Sample splitting can be used to generate Y from X when observations are independent.
Checks are performed to ensure the compatibility of the dimensions of the data and dependence structures, and to verify the positive-definiteness of U and Sigma.
Usage
setup.model(
X,
U = NULL,
Sigma = NULL,
Y = NULL,
UY = NULL,
precUY = NULL,
sample_split = FALSE,
nY = NULL,
verbose = TRUE
)Arguments
- X
Data matrix of size \(n \times p\) containing the observations and variables to be clustered and tested.
- U
Optional \(n \times n\) positive-definite matrix representing the dependence structure among observations in
X. If not provided, observations are considered independent with unit variance.- Sigma
Optional \(p \times p\) positive-definite matrix representing the dependence structure among variables in
X. If not provided, it is estimated usingYandUY.- Y
Optional \(n_Y \times p\) data matrix containing an i.i.d. sample of the same variables as in
X, used to estimateSigmawhen it is not provided. If not provided andsample_split = TRUE,Yis generated by sample splitting fromX. If provided by the user, it must satisfy \(n_Y > p\), i.e.nrow(Y) > ncol(Y).- UY
Optional \(n_Y \times n_Y\) positive-definite matrix representing the dependence structure among observations in
Y. If not provided, observations inYare considered independent with unit variance.- precUY
Optional \(n_Y \times n_Y\) positive-definite matrix representing the inverse of
UY. IfUYis provided butprecUYis not,precUYis computed as the inverse ofUY. If neitherUYnorprecUYis provided, observations inYare considered independent with unit variance.- sample_split
Logical indicating whether to generate
Yby sample splitting fromXwhenSigmais not provided. IfTRUE,Yis generated by randomly splitting the observations inXinto two disjoint sets, one for clustering and testing, and the other for estimatingSigma. IfFALSE, an i.i.d. sampleYmust be provided to estimateSigma.- nY
Optional integer specifying the number of observations in
Ywhensample_split = TRUE. If not provided, it defaults to half of the sample size ofX. Must be strictly greater thanncol(X).- verbose
Logical. Whether to print informational messages about the setup steps (e.g., default choices for
UorSigma). Warnings are always shown regardless of this argument. Default isTRUE.
Value
A list containing the following elements:
- X
Data matrix of size \(n \times p\) containing the observations and variables to be clustered and tested. If
sample_split = TRUE,Xcontains only the observations used for clustering and testing after sample splitting.- U
\(n \times n\) positive-definite matrix representing the dependence structure among observations in
X. If not provided, it is set to the identity matrix.- Sigma
\(p \times p\) positive-definite matrix representing the dependence structure among variables in
X. If not provided, it is estimated usingYandUY.
Examples
# Example with independent observations and known Sigma
X <- matrix(rnorm(100 * 5), nrow = 100, ncol = 5)
Sigma <- diag(5)
setup_result <- setup.model(X = X, Sigma = Sigma)
#> U is not provided: observations are considered independent with unit variance.
print(setup_result)
#> $X
#> 100 x 5 Matrix of class "dgeMatrix"
#> [,1] [,2] [,3] [,4] [,5]
#> [1,] 1.51167228 -1.514497008 1.11343318 -0.722753124 -1.403933837
#> [2,] -0.47569828 -0.061707422 0.83739440 -0.629164665 1.440893147
#> [3,] 0.79791644 -0.147270790 0.31451677 -1.816206055 -0.981359991
#> [4,] -0.97400256 1.541593069 0.22221807 -0.259289098 1.474244904
#> [5,] 0.68937270 -0.981855669 -0.84361539 0.334632273 -0.991197245
#> [6,] -0.95583910 0.496578173 0.44380533 -1.427167613 -0.094497345
#> [7,] -1.23170706 1.696947881 0.05579711 1.938628233 -2.875141684
#> [8,] -0.95689188 -0.260736309 0.06797239 -0.759530213 -0.246866101
#> [9,] -0.86978287 -0.705928586 -0.20196174 -2.278776142 0.014744485
#> [10,] -0.91068068 -0.161178506 -1.15801525 -0.114050766 -1.919087703
#> [11,] 0.74127631 0.501321828 -0.59274327 2.351856666 -0.287813744
#> [12,] 0.06851153 -1.013539670 0.76606538 1.596320803 -0.346637445
#> [13,] -0.32375075 1.614752235 0.03892812 1.277445511 -1.839588585
#> [14,] -1.08650305 0.005641985 0.01464681 0.788970858 0.898588941
#> [15,] -1.01592895 -2.904899060 -0.18631697 0.461465382 -1.212855011
#> [16,] -0.76779018 -1.107164819 1.40059083 -0.438069134 -0.218964232
#> [17,] -1.11972006 1.547566933 0.01848557 -1.507807009 0.564268161
#> [18,] -0.44817424 -0.976830350 0.24919601 -2.222946131 -0.525434376
#> [19,] 0.47173637 -0.101503448 0.14922074 -1.178672442 0.744374225
#> [20,] -1.18049068 0.042650250 -0.96323318 -1.782760224 0.128981753
#> [21,] 1.47025700 -1.596718014 -0.06646677 -0.987919139 1.488274257
#> [22,] -1.31142059 0.490967373 1.28692204 0.728488688 -0.662681951
#> [23,] -0.09652492 0.421603365 0.45812526 -0.884684915 -1.160655001
#> [24,] 2.36971991 1.873903899 -1.45202829 -1.538441417 0.358774234
#> [25,] 0.89062648 1.034514324 0.07734228 -1.044375407 -0.194846384
#> [26,] -0.25218316 0.081810310 0.55989527 -1.718136190 -0.295282008
#> [27,] -0.86576375 -0.082523762 -0.07494657 0.803757539 0.496640424
#> [28,] 0.58258600 0.606073431 0.78269770 -1.501787170 0.484912788
#> [29,] -0.01252935 -0.887420145 -0.17266856 -0.145499071 0.018784501
#> [30,] -0.37485476 0.105421390 -1.05129378 0.579458612 0.634774565
#> [31,] 0.31788574 0.352874473 0.72945128 1.201525576 0.754444088
#> [32,] -0.48880563 0.550393358 0.26266524 1.893910787 0.833589035
#> [33,] 2.65865803 -1.134330969 0.54365786 -1.760226343 0.965761296
#> [34,] 1.68027820 1.462351539 1.04106030 0.924546803 1.293879968
#> [35,] 0.77958401 0.702116711 0.19750615 -0.556542168 -0.136551021
#> [36,] 0.71324052 2.507111148 -1.62957829 -0.180584138 -0.440138688
#> [37,] -0.54288194 -1.890027144 0.12104023 1.447440285 -1.227283914
#> [38,] 0.88577837 -0.589812790 -1.63742195 -0.607131453 -0.237653068
#> [39,] -0.34859468 -1.714502297 -0.53104311 0.679362430 -0.926858157
#> [40,] -1.00805458 -0.420997898 0.95367979 -0.093557640 0.411235356
#> [41,] 1.88318254 0.310141377 -1.72065066 -0.490086292 -0.198864577
#> [42,] -0.92897108 1.702570586 0.10632062 1.410659383 -0.557449639
#> [43,] -0.29419645 -0.443384804 -0.60866850 -0.224573790 -0.977157122
#> [44,] -0.61495027 -1.198597083 -0.30119698 -0.212495490 0.060735249
#> [45,] -0.94707579 -0.307380914 0.97620252 0.696378474 -0.597229480
#> [46,] 0.59897515 0.621054203 0.45600867 0.915182505 -1.258948697
#> [47,] -1.52361488 0.181902191 1.29440807 -0.923374316 -1.410047202
#> [48,] -0.20618900 1.318400931 -1.13320221 1.146873263 1.101304079
#> [49,] -0.57429541 -0.298909313 -0.86946035 -0.635865043 -0.677242026
#> [50,] -1.39016604 -1.648221742 -0.75497029 -0.886443308 -0.762173508
#> [51,] -0.07041738 0.951498470 -0.12963535 -2.333136685 -0.291748602
#> [52,] -0.43087953 -1.113122953 -1.00180134 -0.145490805 -0.575188529
#> [53,] -0.59222537 0.616966476 -0.81986828 0.316964024 -0.443941868
#> [54,] 0.98111616 0.513493716 -0.97455247 -0.707469988 -0.312570444
#> [55,] 0.53240936 0.369459104 0.60430941 1.242155558 -0.603004426
#> [56,] -0.09045612 1.723894131 0.54878759 0.620152195 -1.093934720
#> [57,] 0.15649049 -0.206144567 0.91643266 0.099903068 0.714706191
#> [58,] -0.73731169 -1.314195140 2.66156637 1.807703488 -0.108812263
#> [59,] -0.20134121 0.063474096 -0.18025707 -1.502429979 -1.443797935
#> [60,] 1.10217660 -0.231977451 0.68501477 0.285640465 0.806123264
#> [61,] -0.01674826 0.635060328 3.26641452 0.845706964 -1.739835078
#> [62,] 0.16178863 1.634644285 0.56060046 -0.995342638 -0.401320309
#> [63,] 2.02476139 -1.808327579 -0.06901730 -0.256854125 -0.287582489
#> [64,] -0.70369425 -0.213885951 -0.97244294 -0.055856043 -0.938407400
#> [65,] 0.96079238 0.070366141 -0.54658659 -0.445005240 0.287667139
#> [66,] 1.79048505 0.549707670 -1.68869233 0.069695103 -1.505401124
#> [67,] -1.06416516 -0.696823546 -1.57237270 -0.154671706 1.519297013
#> [68,] 0.01763655 0.390565942 -0.40498716 -0.831263459 0.367409356
#> [69,] -0.38990863 0.381411259 0.31928642 0.761544352 1.699862409
#> [70,] -0.49083275 -0.012372770 0.04042768 -0.576506933 0.644196977
#> [71,] -1.04571765 -0.124434986 -0.39000956 -0.626368228 -1.687801029
#> [72,] -0.89621126 1.466744593 -1.81922223 0.481335326 0.647645994
#> [73,] 1.26938716 0.673928676 0.65918071 1.695271084 0.448794227
#> [74,] 0.59384095 1.956425263 0.45962167 -1.761226294 1.026302158
#> [75,] 0.77563432 -0.269041012 1.61662634 0.198013015 1.074978223
#> [76,] 1.55737038 -1.244551518 -1.85619049 0.397349099 0.458309613
#> [77,] -0.36540180 -0.395702923 -0.28682388 0.029225495 0.631586758
#> [78,] 0.81655645 0.097396655 1.75032189 2.560273389 -0.580466398
#> [79,] -0.06063478 -0.238386950 0.11641361 1.257127712 1.584192142
#> [80,] -0.50137832 -0.411827957 1.38425316 -0.534537686 -1.763992940
#> [81,] 0.92606273 -1.577218049 0.57422091 -0.625227429 -1.880621970
#> [82,] 0.03693769 -0.797276101 0.13649081 0.913848687 -1.291719044
#> [83,] -1.06620017 -1.096236783 0.91421599 1.007199535 0.909670446
#> [84,] -0.23845635 0.308308749 -1.80082632 0.719291823 -1.107755682
#> [85,] 1.49522344 0.344795124 -0.33988064 -0.604711661 -0.384123875
#> [86,] 1.17215855 1.539648088 0.60626457 0.539054406 0.082734834
#> [87,] -1.45770721 -0.329514192 1.34113031 -0.076830886 -0.483882474
#> [88,] 0.09505623 0.948389351 0.76728729 1.849919560 -2.084741125
#> [89,] 0.84766496 -0.479255587 0.19372567 -0.854907551 1.167586964
#> [90,] -1.62436453 -1.514886795 1.14056669 0.032637295 -0.076825771
#> [91,] 1.40856336 0.434536656 0.01386480 -1.025059481 0.530421395
#> [92,] -0.54176036 -0.519536667 -1.10530591 -0.982249076 0.004908796
#> [93,] 0.27866472 -0.834559033 -0.02516264 0.004101957 -0.530231430
#> [94,] -0.19397274 -0.756647609 -0.16367334 -0.233427178 1.514866654
#> [95,] 1.57615818 1.089503495 0.37005975 -0.498888219 0.815459636
#> [96,] -1.47554764 1.572432917 -0.38082454 1.549712963 -1.506521863
#> [97,] -0.14460821 1.007364366 0.65295237 0.087496917 -1.157180172
#> [98,] -0.95320315 -0.273157993 2.06134181 1.318701131 1.301554937
#> [99,] 0.40654273 -1.309679542 -1.79664494 -0.981224119 -0.905640775
#> [100,] 2.22926220 0.222573831 0.58407712 -0.245622588 0.015563481
#>
#> $U
#> 100 x 100 diagonal matrix of class "ddiMatrix", with diagonal entries
#> [1] 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1
#> [38] 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1
#> [75] 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1
#>
#> $Sigma
#> 5 x 5 diagonal matrix of class "ddiMatrix"
#> [,1] [,2] [,3] [,4] [,5]
#> [1,] 1 . . . .
#> [2,] . 1 . . .
#> [3,] . . 1 . .
#> [4,] . . . 1 .
#> [5,] . . . . 1
#>
# Example with dependent observations and unknown Sigma, using sample splitting
X <- matrix(rnorm(100 * 5), nrow = 100, ncol = 5)
U <- matrix(0.3, nrow = 100, ncol = 100)
diag(U) <- 1
setup_result <- setup.model(X = X, U = U, sample_split = TRUE)
#> Sigma not provided: plugging an over-estimate.
print(setup_result)
#> $X
#> 50 x 5 Matrix of class "dgeMatrix"
#> [,1] [,2] [,3] [,4] [,5]
#> [1,] -0.510742458 -1.08542241 -0.65483531 0.24195408 -2.302512517
#> [2,] -0.291842736 0.95983242 1.18657520 0.07035250 1.175894863
#> [3,] 0.649421934 -0.25639230 0.95086737 -0.39223091 -0.501007298
#> [4,] 1.276020709 -0.98214721 0.20017731 -0.28355300 0.387769029
#> [5,] -0.047611220 0.32690556 -0.84719049 -1.16580298 -1.817656629
#> [6,] -0.003580270 1.18372412 0.69510462 -2.05653763 1.366606514
#> [7,] -2.034572643 -0.08861692 -1.57291787 -0.15417450 0.190588625
#> [8,] 1.963858056 0.08681257 -1.15491866 1.21615086 -1.405579071
#> [9,] 0.706528773 -0.29500503 -0.92520123 -0.51117114 2.172244168
#> [10,] -0.162257551 0.38454372 -0.82843838 -0.21273973 -0.261532000
#> [11,] 0.780699292 -0.28596579 1.41644085 -3.08236362 -0.910911965
#> [12,] -0.429033676 1.95027779 2.96174336 0.32559371 -1.658033573
#> [13,] 0.508776266 0.96445407 -0.15782718 -0.56553782 0.400994752
#> [14,] -1.446889743 1.03840459 1.81942527 0.69889868 -2.348004883
#> [15,] 1.019512829 1.76887362 0.86374255 0.88071510 0.730477590
#> [16,] 1.178546976 -0.57165015 -1.56644322 -0.22775497 0.755255204
#> [17,] -0.010258765 -1.47028289 0.51545597 0.13630075 0.788566380
#> [18,] 0.268624871 -1.11036644 0.69621951 1.84340823 -0.342063446
#> [19,] 1.342028872 0.25440339 0.02542110 -1.40539172 1.823848892
#> [20,] -0.937000891 -2.71592529 2.24535874 0.79415451 -0.971565897
#> [21,] -0.711413598 -0.05667276 1.24835851 1.35439733 -1.278265506
#> [22,] -0.943514417 -1.30942995 0.24555952 -1.03745248 0.046567748
#> [23,] -0.274367308 -0.70669129 -0.77872356 -0.03617214 -0.908244134
#> [24,] 0.154468494 1.03389167 -1.79088618 -0.55435061 -0.218683231
#> [25,] -1.288653202 1.97276097 -0.16752386 -0.55886675 -0.155295420
#> [26,] 1.323700599 0.73824255 -0.01702340 -0.90795985 1.769289381
#> [27,] -0.376196737 0.92380003 -0.73357178 -0.73898176 0.156912588
#> [28,] 0.783127640 2.15270084 -1.38185471 -0.09776513 -0.571797205
#> [29,] 0.229284475 1.02950822 -0.78631016 0.95706366 0.340690847
#> [30,] 0.336850949 1.37715475 -0.74248224 0.55933417 0.735364418
#> [31,] -0.647231999 0.91481105 -0.39098025 -0.49770072 -1.024828130
#> [32,] 1.161751761 -0.15173862 -0.89040559 0.08633493 -1.915180723
#> [33,] -0.682467580 0.86857743 0.37183911 -0.96991802 1.135716960
#> [34,] -0.584849244 -1.22233197 -0.02454386 0.75550915 -1.157504888
#> [35,] 1.129936001 -0.71144470 -0.91768924 -0.70325229 0.496621993
#> [36,] 0.581201043 -1.42403167 -0.59188422 -0.28685156 -1.331908129
#> [37,] 0.379293067 -1.66934441 -0.37099306 1.84110689 1.592628620
#> [38,] -0.310740876 1.37923613 0.08792426 -0.15676431 0.061958081
#> [39,] 0.886390001 -0.91967458 -0.03472634 -1.38980264 -0.145945861
#> [40,] -1.641864750 -0.50449004 1.80637427 -1.47310399 -0.343735779
#> [41,] 0.156056926 0.52798878 -1.63913684 0.25041991 -0.002131136
#> [42,] -0.287458172 -0.46203636 2.59577184 -1.97539996 -0.814033523
#> [43,] 0.003854672 1.51344748 -0.16576500 -1.47314013 -0.628854148
#> [44,] 0.980223359 -0.43053694 1.44433440 -1.40341629 -0.953274417
#> [45,] 1.511868401 -1.34572179 0.10619132 0.42196879 -0.766182568
#> [46,] -0.645182435 -0.39889130 -1.51103873 -1.15594311 -0.808773130
#> [47,] 0.567249697 1.31560505 -0.88018810 1.38545119 0.714887190
#> [48,] 0.455884554 -0.44449642 1.06875896 -0.63849508 -0.768700129
#> [49,] -1.197934626 0.56618308 1.16673686 0.23980445 -1.877124097
#> [50,] -2.018180550 0.29032567 2.02995850 -1.00077442 -0.770522589
#>
#> $U
#> 50 x 50 Matrix of class "dsyMatrix"
#> [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13]
#> [1,] 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [2,] 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [3,] 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [4,] 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [5,] 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [6,] 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [7,] 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3
#> [8,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3
#> [9,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3
#> [10,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3
#> [11,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3
#> [12,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3
#> [13,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0
#> [14,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [15,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [16,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [17,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [18,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [19,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [20,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [21,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [22,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [23,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [24,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [25,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [26,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [27,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [28,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [29,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [30,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [31,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [32,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [33,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [34,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [35,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [36,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [37,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [38,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [39,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [40,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [41,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [42,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [43,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [44,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [45,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [46,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [47,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [48,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [49,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [50,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [,14] [,15] [,16] [,17] [,18] [,19] [,20] [,21] [,22] [,23] [,24] [,25]
#> [1,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [2,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [3,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [4,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [5,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [6,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [7,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [8,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [9,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [10,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [11,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [12,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [13,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [14,] 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [15,] 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [16,] 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [17,] 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [18,] 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [19,] 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3
#> [20,] 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3
#> [21,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3
#> [22,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3
#> [23,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3
#> [24,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3
#> [25,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0
#> [26,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [27,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [28,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [29,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [30,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [31,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [32,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [33,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [34,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [35,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [36,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [37,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [38,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [39,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [40,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [41,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [42,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [43,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [44,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [45,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [46,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [47,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [48,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [49,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [50,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [,26] [,27] [,28] [,29] [,30] [,31] [,32] [,33] [,34] [,35] [,36] [,37]
#> [1,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [2,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [3,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [4,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [5,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [6,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [7,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [8,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [9,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [10,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [11,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [12,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [13,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [14,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [15,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [16,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [17,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [18,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [19,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [20,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [21,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [22,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [23,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [24,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [25,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [26,] 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [27,] 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [28,] 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [29,] 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [30,] 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [31,] 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3
#> [32,] 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3
#> [33,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3
#> [34,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3
#> [35,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3
#> [36,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3
#> [37,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0
#> [38,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [39,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [40,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [41,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [42,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [43,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [44,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [45,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [46,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [47,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [48,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [49,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [50,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [,38] [,39] [,40] [,41] [,42] [,43] [,44] [,45] [,46] [,47] [,48] [,49]
#> [1,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [2,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [3,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [4,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [5,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [6,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [7,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [8,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [9,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [10,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [11,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [12,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [13,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [14,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [15,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [16,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [17,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [18,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [19,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [20,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [21,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [22,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [23,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [24,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [25,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [26,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [27,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [28,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [29,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [30,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [31,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [32,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [33,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [34,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [35,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [36,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [37,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [38,] 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [39,] 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [40,] 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [41,] 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [42,] 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [43,] 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3 0.3
#> [44,] 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3 0.3
#> [45,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3 0.3
#> [46,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3 0.3
#> [47,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3 0.3
#> [48,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0 0.3
#> [49,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 1.0
#> [50,] 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3 0.3
#> [,50]
#> [1,] 0.3
#> [2,] 0.3
#> [3,] 0.3
#> [4,] 0.3
#> [5,] 0.3
#> [6,] 0.3
#> [7,] 0.3
#> [8,] 0.3
#> [9,] 0.3
#> [10,] 0.3
#> [11,] 0.3
#> [12,] 0.3
#> [13,] 0.3
#> [14,] 0.3
#> [15,] 0.3
#> [16,] 0.3
#> [17,] 0.3
#> [18,] 0.3
#> [19,] 0.3
#> [20,] 0.3
#> [21,] 0.3
#> [22,] 0.3
#> [23,] 0.3
#> [24,] 0.3
#> [25,] 0.3
#> [26,] 0.3
#> [27,] 0.3
#> [28,] 0.3
#> [29,] 0.3
#> [30,] 0.3
#> [31,] 0.3
#> [32,] 0.3
#> [33,] 0.3
#> [34,] 0.3
#> [35,] 0.3
#> [36,] 0.3
#> [37,] 0.3
#> [38,] 0.3
#> [39,] 0.3
#> [40,] 0.3
#> [41,] 0.3
#> [42,] 0.3
#> [43,] 0.3
#> [44,] 0.3
#> [45,] 0.3
#> [46,] 0.3
#> [47,] 0.3
#> [48,] 0.3
#> [49,] 0.3
#> [50,] 1.0
#>
#> $Sigma
#> 5 x 5 Matrix of class "dgeMatrix"
#> [,1] [,2] [,3] [,4] [,5]
#> [1,] 1.05298886 -0.01938594 0.1622737 -0.25068013 0.29348222
#> [2,] -0.01938594 1.13578655 0.1895796 -0.05137562 -0.07415423
#> [3,] 0.16227371 0.18957962 1.2802447 -0.17181381 -0.27211392
#> [4,] -0.25068013 -0.05137562 -0.1718138 1.92973993 -0.02848115
#> [5,] 0.29348222 -0.07415423 -0.2721139 -0.02848115 1.28984099
#>