Validates the ndraws argument used to approximate the p-value for
complete-linkage hierarchical clustering in test.clusters.hc. A
valid ndraws must be a single positive, finite integer.
Usage
validate_ndraws(ndraws)
Arguments
ndraws
A value intended to be used as the number of Monte-Carlo
draws.